@@ -1,9 +1,21 @@
 ( cd opt/kde/share/doc/HTML/ca/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kdf ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kdm ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kpf ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/amor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/amor ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kate ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kate ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kdat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kdat ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kgpg ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kmag ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kodo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kodo ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/krdc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/krdc ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/krfb ; rm -rf common )
@@ -20,6 +32,8 @@
 ( cd opt/kde/share/doc/HTML/ca/khangman ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kpercentage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kpercentage ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kdcop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kdcop ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kdesu ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kcron ; rm -rf common )
@@ -30,16 +44,30 @@
 ( cd opt/kde/share/doc/HTML/ca/kmail ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kmoon ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/ktnef ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/ksysv ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kttsd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kttsd ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kuser ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/klipper ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kmousetool ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kompare ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kompmgr ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kompmgr ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kontact ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/konsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/konsole ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kpackage ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/lilo-config ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/lilo-config ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/khelpcenter/quickstart ; rm -rf common )
@@ -56,116 +84,16 @@
 ( cd opt/kde/share/doc/HTML/ca/kwallet ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kweather ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kioslave ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf fdl-license )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/fdl-license fdl-license )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf qpl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf x11-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 1.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/1.png 1.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf xml.dcl )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 2.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/2.png 2.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 3.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/3.png 3.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 4.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/4.png 4.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 5.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/5.png 5.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 6.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/6.png 6.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 7.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/7.png 7.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 8.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/8.png 8.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 9.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/9.png 9.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf headerbg.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf gpl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf mainheader.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf grad.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/grad.png grad.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf kde-web.css )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf lgpl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf doxygen.css )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf web-doctop.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf kde-default.css )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf kmenu.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf footer.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/footer.html footer.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf kde-common.css )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf bottom-left.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf appheader.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/appheader.html appheader.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf doctop1.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf doctop2.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf shadow.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/shadow.png shadow.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf kde_logo.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf docheadergears.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf top-middle.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf fdl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf bottom-right.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf doctop1a.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf 10.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/10.png 10.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf doctop1b.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf lgpl-license )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf mainfooter.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf bottom1.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf bottom2.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf header.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/header.html header.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf bottom-middle.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf top-left.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/top-left.png top-left.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf gpl-license )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/gpl-license gpl-license )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf bsd-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf web-docbottom.png )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
-( cd opt/kde/share/doc/HTML/ca/common ; rm -rf artistic-license.html )
-( cd opt/kde/share/doc/HTML/ca/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/ca/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/knetattach ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kcontrol/smb ; rm -rf common )
@@ -272,6 +200,10 @@
 ( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kcontrol/performance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kicker-applets ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/konq-plugins/crashes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/konq-plugins/babel ; rm -rf common )
@@ -300,6 +232,8 @@
 ( cd opt/kde/share/doc/HTML/ca/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/konq-plugins/dirfilter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kdeprint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kdeprint ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kbruch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kbruch ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/keduca ; rm -rf common )
@@ -308,6 +242,8 @@
 ( cd opt/kde/share/doc/HTML/ca/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kicker ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kmouth ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kpager ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kspell ; rm -rf common )
@@ -318,24 +254,74 @@
 ( cd opt/kde/share/doc/HTML/ca/ktimer ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/ktouch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/ktouch ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kwrite ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kwrite ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/ksplashml ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/ksplashml ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kcharselect ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/quanta ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/klettres ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/klickety ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kgeography ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kgeography ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kleopatra ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kleopatra ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kworldclock ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kteatime ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kteatime ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/knetworkconf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/pci ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/usb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/nics ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/interrupts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kinfocenter/blockdevices ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/xserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/samba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/sound ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/partitions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/cdinfo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/cdinfo ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/pcmcia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/processor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/ioports ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
+( cd opt/kde/share/doc/HTML/ca/kate-plugins ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ca/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ca/konqueror ; ln -sf /opt/kde/share/doc/HTML/ca/common common )
 ( cd opt/kde/share/doc/HTML/ca/kwordquiz ; rm -rf common )
